@@ -1,19 +1,14 @@
 # coding: utf-8
-"""JupyterLab Server"""
+"""JupyterLab Server Application"""
 
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-import os, jinja2
-from traitlets import Unicode
-from jinja2 import Environment, FileSystemLoader
-from traitlets import Bool, Unicode, default, observe
 from jupyter_server.extension.application import ExtensionApp, ExtensionAppJinjaMixin
-from traitlets import Unicode, Integer, Dict
+from traitlets import Dict, Integer, Unicode, observe
 
 from ._version import __version__
-from .server import url_path_join as ujoin
-from .handlers import add_handlers, LabConfig
+from .handlers import LabConfig, add_handlers
 
 
 class LabServerApp(ExtensionAppJinjaMixin, LabConfig, ExtensionApp):
@@ -48,7 +43,7 @@ class LabServerApp(ExtensionAppJinjaMixin, LabConfig, ExtensionApp):
         """)
 
     whitelist_uris = Unicode('', config=True,
-        help="A list of comma-separated URIs to get the whitelist")
+        help="Deprecated, use `LabServerApp.allowed_extensions_uris`")
 
     allowed_extensions_uris = Unicode('', config=True,
         help="""
